@@ -1,12 +1,9 @@
-from asyncio.log import logger
 import inspect
-from tokenize import group
 from aiohttp import ClientSession, ClientWebSocketResponse
 import asyncio
-from typing import Awaitable, BinaryIO, Dict, List, Optional, Union, AsyncGenerator
-
+from typing import Awaitable, BinaryIO, Callable, Dict, List, Optional, Tuple, Union, AsyncGenerator
 import aiohttp
-from karas.util import status_code_exception
+from karas.util import DefaultNamespace, status_code_exception
 from karas.util.sync import async_to_sync_wrap
 from karas.chain import MessageChain
 from karas.Sender import Friend, Group, Member, Stranger, ReceptorBase, Announcement
@@ -14,12 +11,12 @@ from karas.messages import MessageBase
 from karas.event import Auto_Switch_Event, EventBase, MemberJoinRequestEvent, NewFriendRequestEvent, RequestEvent, Event, NudgeEvent
 from karas.elements import ElementBase, File, FlashImage, GroupConfig, Image, MemberInfo, Plain, Source, Voice, FriendProfile, MemberProfile, \
     BotProfile, UserProfile
-from karas.exceptions import ConnectException, FunctionException
+from karas.exceptions import *
 from karas.util.Logger import Logging
 from karas.util.network import error_throw, URL_Route, wrap_data_json
 
 
-__version__ = "0.1.6"
+__version__ = "0.1.8"
 
 
 async def _build_content_json(
@@ -41,6 +38,7 @@ class Karas(object):
         负责处理消息事件
     """
     listeners = {}
+    loop: asyncio.AbstractEventLoop = None
 
     @classmethod
     async def event_parse(cls, original: dict, _logger: Logging = None) -> AsyncGenerator:
@@ -64,8 +62,12 @@ class Karas(object):
         if cls.listeners.get(message.type) is None:
             return
         for listener in cls.listeners.get(message.type):
+            ca, cb, cb_args = listener
+            if cb:
+                cb_args = cb_args or ()
+                cb(message.raw, *cb_args)
             _message_dict = message.__dict__
-            _func_params = listener.__annotations__
+            _func_params = ca.__annotations__
 
             _reversed = {_v if isinstance(type, type(_v)) else type(
                 _v): _k for _k, _v in _message_dict.items()}
@@ -75,10 +77,10 @@ class Karas(object):
             for k, t in _func_params.items():
                 if t in _types:
                     _o[k] = _message_dict[_reversed[t]]
-            if inspect.iscoroutinefunction(listener):
-                await listener(**_o)
+            if inspect.iscoroutinefunction(ca):
+                cls.loop.create_task(ca(**_o))
             else:
-                listener(**_o)
+                ca(**_o)
 
 
 @async_to_sync_wrap
@@ -119,9 +121,13 @@ class Yurine(object):
             loggerLevel, qq, filename=logFileName, logFile=logToFile)
         self._loop = loop or self._get_event_loop()
         self.karas = karas or Karas
+        self.karas.loop = self.loop
+
+        self.namespace = DefaultNamespace
 
         self._is_running = False
         self._receiver_is_running = False
+        self._receivData = {}
 
     @property
     def host(self):
@@ -197,9 +203,10 @@ class Yurine(object):
         while True:
             try:
                 await self.ws.ping()
-            except Exception as e:
-                self.logging.warning("connect reset, retry...")
-                await asyncio.sleep(1)
+            except ConnectionResetError:
+                return
+            except Exception:
+                raise
             else:
                 await asyncio.sleep(.5)
 
@@ -230,18 +237,35 @@ class Yurine(object):
         """事件监听器"""
         self._receiver_is_running = True
         while True:
-            _receive_data: dict = await self.ws.receive_json()
-            if _receive_data.get("syncId") == "-1":
+            try:
+                _receive_data: Dict = await self.ws.receive_json()
+            except (BotBaseException, TypeError):
+                pass
+            except Exception:
+                raise
+            syncId = _receive_data.get("syncId")
+            if syncId == "-1":
                 _parser = self.karas.event_parse(
                     _receive_data["data"], self.logging)
                 _event = await _parser.__anext__()
                 await _parser.asend(self.account == _event.event.fromId) \
                     if isinstance(_event, Event) else await _parser.asend(False)
+            elif syncId:
+                self.logging.debug(f"sync Event {_receive_data}")
+                self._receivData[syncId] = _receive_data
+            else:
+                self.logging.debug(f"Unknown event:{_receive_data}")
 
-    def listen(self, registerEvent: Union[str, "EventBase", "MessageBase"]):
+    def listen(self, registerEvent: Union[str, "EventBase", "MessageBase"], callback: Callable = None, cb_args: Optional[Tuple] = None):
         """事件装饰器
         Args:
             registerEvent (str, Event, Message): 要监听的事件或者消息类型
+            callback: 设定一个callback,当监听到指定事件会将该事件原始数据(Dict)作为第一个参数传入
+            cb_args:传入到callback的其他参数
+
+            callback用法:
+            def callback(eventData: Dict, arg1, arg2,...) -> ...: ...
+            @listen(GroupMessage, callback=callback, cb_args=(a1,a2,a3)0) -> None:...
 
         Returns:
             None: NoReturn
@@ -250,15 +274,17 @@ class Yurine(object):
             registerEvent = registerEvent if isinstance(
                 registerEvent, str) else registerEvent.type
 
-        def register_decorator(Callable: Awaitable):
+        def register_decorator(callable: Awaitable):
             def register_wrapper(*args, **kwargs):
                 self.logging.debug(
-                    f"register listener [{Callable.__name__}] for Event[{registerEvent}]"
+                    f"register listener [{callable.__name__}] for Event[{registerEvent}]"
                 )
                 if Karas.listeners.get(registerEvent):
-                    Karas.listeners.get(registerEvent).append(Callable)
+                    Karas.listeners.get(registerEvent).append(
+                        (callable, callback, cb_args))
                 else:
-                    Karas.listeners[registerEvent] = [Callable, ]
+                    Karas.listeners[registerEvent] = [
+                        (callable, callback, cb_args)]
             return register_wrapper()
         return register_decorator
 
@@ -275,7 +301,7 @@ class Yurine(object):
             message (str, optional): 同意该请求时附带的消息. Defaults to None.
         """
         if not isinstance(requestEvent, RequestEvent):
-            logger.error("非法请求")
+            self.logging.error("非法请求")
         else:
             requestEvent.message = message
             await self.ws.send_json(
@@ -299,7 +325,7 @@ class Yurine(object):
             message (str, optional): 拒绝该请求时附带的消息. Defaults to None.
         """
         if not isinstance(requestEvent, RequestEvent):
-            logger.error("非法请求")
+            self.logging.error("非法请求")
         else:
             requestEvent.message = message
             await self.ws.send_json(
@@ -323,7 +349,7 @@ class Yurine(object):
             message (str, optional): 拒绝该请求时附带的消息. Defaults to None.
         """
         if not isinstance(requestEvent, [NewFriendRequestEvent, MemberJoinRequestEvent]):
-            logger.error("非法请求")
+            self.logging.error("非法请求")
         else:
             requestEvent.message = message
             await self.ws.send_json(
@@ -347,7 +373,7 @@ class Yurine(object):
             message (str, optional): 忽略该请求时附带的消息. Defaults to None.
         """
         if not isinstance(requestEvent, RequestEvent):
-            logger.error("非法请求")
+            self.logging.error("非法请求")
         else:
             requestEvent.message = message
             await self.ws.send_json(
@@ -371,7 +397,7 @@ class Yurine(object):
             message (str, optional): 忽略该请求时附带的消息. Defaults to None.
         """
         if not isinstance(requestEvent, RequestEvent):
-            logger.error("非法请求")
+            self.logging.error("非法请求")
         else:
             requestEvent.message = message
             await self.ws.send_json(
@@ -433,12 +459,14 @@ class Yurine(object):
     @error_throw
     async def about(self):
         """获取mirai-api-http的版本"""
+        syncId = self.namespace.gen()
         await self.ws.send_json(
             wrap_data_json(
+                syncId=syncId,
                 command="about",
             )
         )
-        version = await self._raise_status()
+        version = await self._raise_status(syncId=syncId)
         return version.get("data").get("version")
 
     @error_throw
@@ -462,14 +490,15 @@ class Yurine(object):
         _chain = [(await self._element_check(_e, type="group", target=group)) for _e in Elements] \
             if not isinstance(Elements, MessageChain) else Elements.parse_to_json()
         content = await _build_content_json("group", group, quote, _chain)
+        syncId = self.namespace.gen()
         await self.ws.send_json(
             wrap_data_json(
-                syncId="sendGroupMessage",
+                syncId=syncId,
                 command="sendGroupMessage",
                 content=content
             ))
         self.logging.info(f"bot <= {MessageChain(*_chain).to_str()}")
-        echo = await self._raise_status()
+        echo = await self._raise_status(syncId=syncId)
         return echo.get("messageId")
 
     @error_throw
@@ -494,15 +523,16 @@ class Yurine(object):
         _chain = [(await self._element_check(_e, type="friend")) for _e in Elements] \
             if not isinstance(Elements, MessageChain) else Elements.parse_to_json()
         content = await _build_content_json("target", friend, quote, _chain)
+        syncId = self.namespace.gen()
         await self.ws.send_json(
             wrap_data_json(
-                syncId="sendFriendMessage",
+                syncId=syncId,
                 command="sendFriendMessage",
                 content=content
             )
         )
         self.logging.info(f"Bot <= {MessageChain(*_chain).to_str()}")
-        echo = await self._raise_status()
+        echo = await self._raise_status(syncId=syncId)
         return echo.get("messageId")
 
     @error_throw
@@ -534,15 +564,16 @@ class Yurine(object):
             quote: quote and quote.id,
             "messageChain": _chain
         }
+        syncId = self.namespace.gen()
         await self.ws.send_json(
             wrap_data_json(
-                syncId="sendTempMessage",
+                syncId=syncId,
                 command="sendTempMessage",
                 content=content
             )
         )
         self.logging.info(f"bot <= {MessageChain(*_chain).to_str()}")
-        echo = await self._raise_status()
+        echo = await self._raise_status(syncId=syncId)
         return echo.get("messageId")
 
     @error_throw
@@ -588,9 +619,10 @@ class Yurine(object):
             else target.group if isinstance(target, Member) else target.id
         kind = kind if kind is not None else event.subject.kind if event is not None \
             else target.group.type if isinstance(target, Member) else target.type
+        syncId = self.namespace.gen()
         await self.ws.send_json(
             wrap_data_json(
-                syncId="sendNudge",
+                syncId=syncId,
                 command="sendNudge",
                 content={
                     "target": target,
@@ -598,7 +630,7 @@ class Yurine(object):
                     "kind": kind
                 }))
         self.logging.info(f"Bot <= NudgeEvent:{subject}")
-        data = await self._raise_status()
+        data = await self._raise_status(syncId=syncId)
         return data
 
     @error_throw
@@ -614,15 +646,17 @@ class Yurine(object):
         Returns:
             Optional[MessageChain]: 包含该条消息的消息链，如果该消息未被缓存返回None
         """
+        syncId = self.namespace.gen()
         await self.ws.send_json(
             wrap_data_json(
+                syncId=syncId,
                 command="messageFromId",
                 content={
                     "id": messageId
                 }
             )
         )
-        message = await self._raise_status()
+        message = await self._raise_status(syncId=syncId)
         return message and MessageChain(*message.get("messageChain"))
 
     @error_throw
@@ -630,12 +664,14 @@ class Yurine(object):
         """
         获取好友列表
         """
+        syncId = self.namespace.gen()
         await self.ws.send_json(
             wrap_data_json(
+                syncId=syncId,
                 command="friendList"
             )
         )
-        data = await self._raise_status()
+        data = await self._raise_status(syncId=syncId)
         return data and [Friend(**friend) for friend in data.get("data")]
 
     @error_throw
@@ -646,15 +682,17 @@ class Yurine(object):
         """
         获取好友详细资料
         """
+        syncId = self.namespace.gen()
         await self.ws.send_json(
             wrap_data_json(
+                syncId=syncId,
                 command="friendProfile",
                 content={
                     "target": friend if isinstance(friend, int) else friend.id
                 }
             )
         )
-        friend = await self._raise_status()
+        friend = await self._raise_status(syncId=syncId)
         return friend and FriendProfile(**friend)
 
     @error_throw
@@ -662,12 +700,14 @@ class Yurine(object):
         """
         获取群列表
         """
+        syncId = self.namespace.gen()
         await self.ws.send_json(
             wrap_data_json(
+                syncId=syncId,
                 command="groupList"
             )
         )
-        data = await self._raise_status()
+        data = await self._raise_status(syncId=syncId)
         return data and [Group(**group) for group in data.get("data")]
 
     @error_throw
@@ -678,15 +718,17 @@ class Yurine(object):
         """
         获取群成员列表
         """
+        syncId = self.namespace.gen()
         await self.ws.send_json(
             wrap_data_json(
+                syncId=syncId,
                 command="memberList",
                 content={
                     "target": group if isinstance(group, int) else group.id
                 }
             )
         )
-        data = await self._raise_status()
+        data = await self._raise_status(syncId=syncId)
         return data and [Member(**member) for member in data.get("data")]
 
     @error_throw
@@ -698,8 +740,10 @@ class Yurine(object):
         """
         获取成员详细资料
         """
+        syncId = self.namespace.gen()
         await self.ws.send_json(
             wrap_data_json(
+                syncId=syncId,
                 command="memberProfile",
                 content={
                     "target": group if isinstance(group, int) else group.id,
@@ -707,7 +751,7 @@ class Yurine(object):
                 }
             )
         )
-        data = await self._raise_status()
+        data = await self._raise_status(syncId=syncId)
         return data and MemberProfile(**data)
 
     @error_throw
@@ -715,12 +759,14 @@ class Yurine(object):
         """
         获取bot详细资料
         """
+        syncId = self.namespace.gen()
         await self.ws.send_json(
             wrap_data_json(
+                syncId=syncId,
                 command="botProfile"
             )
         )
-        data = await self._raise_status()
+        data = await self._raise_status(syncId=syncId)
         return data and BotProfile(**data)
 
     @error_throw
@@ -728,15 +774,17 @@ class Yurine(object):
         """
         获取用户详细资料
         """
+        syncId = self.namespace.gen()
         await self.ws.send_json(
             wrap_data_json(
+                syncId=syncId,
                 command="userProfile",
                 content={
                     "target": target
                 }
             )
         )
-        data = await self._raise_status()
+        data = await self._raise_status(syncId=syncId)
         return data and UserProfile(**data)
 
     @error_throw
@@ -762,8 +810,10 @@ class Yurine(object):
         Returns:
             Optional[List[File]]: 一个文件对象列表
         """
+        syncId = self.namespace.gen()
         await self.ws.send_json(
             wrap_data_json(
+                syncId=syncId,
                 command="file_list",
                 content={
                     "id": id,
@@ -775,7 +825,7 @@ class Yurine(object):
                 }
             )
         )
-        data = await self._raise_status()
+        data = await self._raise_status(syncId=syncId)
         return data and [File(**file) for file in data]
 
     @error_throw
@@ -797,8 +847,10 @@ class Yurine(object):
         Returns:
             Optional[File]: 一个文件对象
         """
+        syncId = self.namespace.gen()
         await self.ws.send_json(
             wrap_data_json(
+                syncId=syncId,
                 command="file_info",
                 content={
                     "id": id,
@@ -808,7 +860,7 @@ class Yurine(object):
                 }
             )
         )
-        data = await self._raise_status()
+        data = await self._raise_status(syncId=syncId)
         return data and File(**data)
 
     @error_throw
@@ -830,8 +882,10 @@ class Yurine(object):
         Returns:
             Optional[File]: 一个文件对象
         """
+        syncId = self.namespace.gen()
         await self.ws.send_json(
             wrap_data_json(
+                syncId=syncId,
                 command="file_mkdir",
                 content={
                     "id": id,
@@ -841,7 +895,7 @@ class Yurine(object):
                 }
             )
         )
-        return await self._raise_status()
+        return await self._raise_status(syncId=syncId)
 
     @error_throw
     async def fileDelete(
@@ -860,8 +914,10 @@ class Yurine(object):
         Returns:
             str: _description_
         """
+        syncId = self.namespace.gen()
         await self.ws.send_json(
             wrap_data_json(
+                syncId=syncId,
                 command="file_delete",
                 content={
                     "id": id,
@@ -870,7 +926,7 @@ class Yurine(object):
                 }
             )
         )
-        return await self._raise_status()
+        return await self._raise_status(syncId=syncId)
 
     @error_throw
     async def fileMove(
@@ -898,8 +954,10 @@ class Yurine(object):
         """
         if moveTo is None and moveToPath is None:
             raise ValueError("必须选择移动至目标的位置")
+        syncId = self.namespace.gen()
         await self.ws.send_json(
             wrap_data_json(
+                syncId=syncId,
                 command="file_move",
                 content={
                     "id": id,
@@ -910,7 +968,7 @@ class Yurine(object):
                 }
             )
         )
-        return await self._raise_status()
+        return await self._raise_status(syncId=syncId)
 
     @error_throw
     async def fileRename(
@@ -956,15 +1014,17 @@ class Yurine(object):
         Returns:
             str: 
         """
+        syncId = self.namespace.gen()
         await self.ws.send_json(
             wrap_data_json(
+                syncId=syncId,
                 command="deleteFriend",
                 content={
                     "target": friend
                 }
             )
         )
-        return await self._raise_status()
+        return await self._raise_status(syncId=syncId)
 
     @error_throw
     async def mute(
@@ -983,8 +1043,10 @@ class Yurine(object):
         Returns:
             str: 
         """
+        syncId = self.namespace.gen()
         await self.ws.send_json(
             wrap_data_json(
+                syncId=syncId,
                 command="mute",
                 content={
                     "target": group,
@@ -993,7 +1055,7 @@ class Yurine(object):
                 }
             )
         )
-        return await self._raise_status()
+        return await self._raise_status(syncId=syncId)
 
     @error_throw
     async def unmute(
@@ -1010,8 +1072,10 @@ class Yurine(object):
         Returns:
             str: 
         """
+        syncId = self.namespace.gen()
         await self.ws.send_json(
             wrap_data_json(
+                syncId=syncId,
                 command="unmute",
                 content={
                     "target": group,
@@ -1019,7 +1083,7 @@ class Yurine(object):
                 }
             )
         )
-        return await self._raise_status()
+        return await self._raise_status(syncId=syncId)
 
     @error_throw
     async def kick(
@@ -1038,8 +1102,10 @@ class Yurine(object):
         Returns:
             str: 
         """
+        syncId = self.namespace.gen()
         await self.ws.send_json(
             wrap_data_json(
+                syncId=syncId,
                 command="kick",
                 content={
                     "target": group,
@@ -1048,7 +1114,7 @@ class Yurine(object):
                 }
             )
         )
-        return await self._raise_status()
+        return await self._raise_status(syncId=syncId)
 
     @error_throw
     async def quit(
@@ -1063,15 +1129,17 @@ class Yurine(object):
         Returns:
             str: _description_
         """
+        syncId = self.namespace.gen()
         await self.ws.send_json(
             wrap_data_json(
+                syncId=syncId,
                 command="quit",
                 content={
                     "target": group
                 }
             )
         )
-        return await self._raise_status()
+        return await self._raise_status(syncId=syncId)
 
     @error_throw
     async def muteAll(
@@ -1086,15 +1154,17 @@ class Yurine(object):
         Returns:
             str: 
         """
+        syncId = self.namespace.gen()
         await self.ws.send_json(
             wrap_data_json(
+                syncId=syncId,
                 command="muteAll",
                 content={
                     "target": group,
                 }
             )
         )
-        return await self._raise_status()
+        return await self._raise_status(syncId=syncId)
 
     @error_throw
     async def unmuteAll(
@@ -1110,15 +1180,17 @@ class Yurine(object):
         Returns:
             str: _description_
         """
+        syncId = self.namespace.gen()
         await self.ws.send_json(
             wrap_data_json(
+                syncId=syncId,
                 command="unmuteAll",
                 content={
                     "target": group if isinstance(group, int) else group.id,
                 }
             )
         )
-        return await self._raise_status()
+        return await self._raise_status(syncId=syncId)
 
     @error_throw
     async def setEssence(
@@ -1133,15 +1205,17 @@ class Yurine(object):
         Returns:
             str: 
         """
+        syncId = self.namespace.gen()
         await self.ws.send_json(
             wrap_data_json(
+                syncId=syncId,
                 command="setEssence",
                 content={
                     "target": messageId if isinstance(messageId, int) else messageId.id
                 }
             )
         )
-        return await self._raise_status()
+        return await self._raise_status(syncId=syncId)
 
     @error_throw
     async def fetchGroupConfig(
@@ -1156,8 +1230,10 @@ class Yurine(object):
         Returns:
             Optional[GroupConfig]: 一个群设置对象
         """
+        syncId = self.namespace.gen()
         await self.ws.send_json(
             wrap_data_json(
+                syncId=syncId,
                 command="groupConfig",
                 subCommand="get",
                 content={
@@ -1165,7 +1241,7 @@ class Yurine(object):
                 }
             )
         )
-        config = await self._raise_status()
+        config = await self._raise_status(syncId=syncId)
         return config and GroupConfig(**config)
 
     @error_throw
@@ -1185,8 +1261,10 @@ class Yurine(object):
         """
         if isinstance(config, GroupConfig):
             config = GroupConfig.__dict__
+        syncId = self.namespace.gen()
         await self.ws.send_json(
             wrap_data_json(
+                syncId=syncId,
                 command="groupConfig",
                 subCommand="set",
                 content={
@@ -1195,7 +1273,7 @@ class Yurine(object):
                 }
             )
         )
-        return await self._raise_status()
+        return await self._raise_status(syncId=syncId)
 
     @error_throw
     async def fetchMemberInfo(
@@ -1212,8 +1290,10 @@ class Yurine(object):
         Returns:
             Optional[Member]: 一个Member对象
         """
+        syncId = self.namespace.gen()
         await self.ws.send_json(
             wrap_data_json(
+                syncId=syncId,
                 command="memberInfo",
                 subCommand="get",
                 content={
@@ -1222,7 +1302,7 @@ class Yurine(object):
                 }
             )
         )
-        info = await self._raise_status()
+        info = await self._raise_status(syncId=syncId)
         return info and Member(**info)
 
     @error_throw
@@ -1244,8 +1324,10 @@ class Yurine(object):
         """
         if isinstance(info, MemberInfo):
             info = MemberInfo.elements
+        syncId = self.namespace.gen()
         await self.ws.send_json(
             wrap_data_json(
+                syncId=syncId,
                 command="memberInfo",
                 subCommand="update",
                 content={
@@ -1255,7 +1337,7 @@ class Yurine(object):
                 }
             )
         )
-        return await self._raise_status()
+        return await self._raise_status(syncId=syncId)
 
     @error_throw
     async def setMemberAdmin(
@@ -1274,8 +1356,10 @@ class Yurine(object):
         Returns:
             str: _description_
         """
+        syncId = self.namespace.gen()
         await self.ws.send_json(
             wrap_data_json(
+                syncId=syncId,
                 command="memberAdmin",
                 content={
                     "target": group,
@@ -1284,7 +1368,7 @@ class Yurine(object):
                 }
             )
         )
-        return await self._raise_status()
+        return await self._raise_status(syncId=syncId)
 
     @error_throw
     async def fetchAnnouncement(
@@ -1303,8 +1387,10 @@ class Yurine(object):
         Returns:
             List[Announcement]: 群公告对象
         """
+        syncId = self.namespace.gen()
         await self.ws.send_json(
             wrap_data_json(
+                syncId=syncId,
                 command="anno_list",
                 content={
                     "id": group,
@@ -1313,7 +1399,7 @@ class Yurine(object):
                 }
             )
         )
-        anno_list = await self._raise_status()
+        anno_list = await self._raise_status(syncId=syncId)
         return anno_list and [Announcement(**anno) for anno in anno_list]
 
     @error_throw
@@ -1344,8 +1430,10 @@ class Yurine(object):
         if isinstance(image, Image):
             image = self.uploadMultipart(image, type="group")
             imageUrl = image.url
+        syncId = self.namespace.gen()
         await self.ws.send_json(
             wrap_data_json(
+                syncId=syncId,
                 command="anno_publish",
                 content={
                     "target": group,
@@ -1359,7 +1447,7 @@ class Yurine(object):
                 }
             )
         )
-        anno = await self._raise_status()
+        anno = await self._raise_status(syncId=syncId)
         return anno and Announcement(**anno)
 
     @error_throw
@@ -1377,8 +1465,10 @@ class Yurine(object):
         Returns:
             str: _description_
         """
+        syncId = self.namespace.gen()
         await self.ws.send_json(
             wrap_data_json(
+                syncId=syncId,
                 command="anno_delete",
                 content={
                     "id": group,
@@ -1386,7 +1476,7 @@ class Yurine(object):
                 }
             )
         )
-        return await self._raise_status()
+        return await self._raise_status(syncId=syncId)
 
     async def _raise_task_cancel(self, _task: asyncio.Task) -> None:
         """取消当前事件循环中的任务"""
@@ -1397,9 +1487,12 @@ class Yurine(object):
             except asyncio.CancelledError:
                 self.logging.debug(f"canceled <task {id(_task)}>")
 
-    # @error_throw
-    async def _raise_status(self, data: Optional[Dict] = None) -> Dict:
-        _json_data = data or await self.ws.receive_json()
+    async def _raise_status(self, data: Optional[Dict] = None, syncId: str = None) -> Dict:
+        try:
+            await asyncio.sleep(.1)
+            _json_data = data or (syncId and self._receivData.get(syncId)) or await self.ws.receive_json()
+        except RuntimeError:
+            return await self._raise_status(data=data, syncId=syncId)
         self.logging.debug(f"recv data {_json_data}")
         _data = _json_data.get("data")
         _status_code = _json_data.get("code") or (_data and _data.get("code"))
@@ -1412,13 +1505,13 @@ class Yurine(object):
         """挂起"""
         self.logging.debug("run_forever")
         if not self._is_running:
-            self.stcart()
+            self.start()
         if not self._receiver_is_running:
             self.loop.create_task(self._receiver())
             self.logging.info(f"receiver created")
         try:
             self.loop.run_forever()
-        except KeyboardInterrupt:
+        except Exception:
             self.logging.info("Bot closing...")
             raise
         finally:
